==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridColumnOptionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { GridColumnSortOptionsDescriptionModule } from "./GridColumnSortOptionsDescriptionModule";
import { GridColumnMoveOptionsDescriptionModule } from "./GridColumnMoveOptionsDescriptionModule";
import { GridColumnPinOptionsDescriptionModule } from "./GridColumnPinOptionsDescriptionModule";
import { GridColumnHideOptionsDescriptionModule } from "./GridColumnHideOptionsDescriptionModule";
import { GridColumnGroupOptionsDescriptionModule } from "./GridColumnGroupOptionsDescriptionModule";
import { GridColumnFilterOptionsDescriptionModule } from "./GridColumnFilterOptionsDescriptionModule";
import { GridColumnSummaryOptionsDescriptionModule } from "./GridColumnSummaryOptionsDescriptionModule";
import { GridColumnButtonOptionsDescriptionModule } from "./GridColumnButtonOptionsDescriptionModule";
import { GridColumnOptionsDescriptionMetadata } from "./GridColumnOptionsDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnOptionsDescriptionModule, _super);
    function GridColumnOptionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsDescriptionModule.register = function (a) {
        GridColumnSortOptionsDescriptionModule.register(a);
        GridColumnMoveOptionsDescriptionModule.register(a);
        GridColumnPinOptionsDescriptionModule.register(a);
        GridColumnHideOptionsDescriptionModule.register(a);
        GridColumnGroupOptionsDescriptionModule.register(a);
        GridColumnFilterOptionsDescriptionModule.register(a);
        GridColumnSummaryOptionsDescriptionModule.register(a);
        GridColumnButtonOptionsDescriptionModule.register(a);
        GridColumnOptionsDescriptionMetadata.d(a);
    };
    GridColumnOptionsDescriptionModule.$t = markType(GridColumnOptionsDescriptionModule, 'GridColumnOptionsDescriptionModule');
    return GridColumnOptionsDescriptionModule;
}(Base));
export { GridColumnOptionsDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridColumnOptionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { GridColumnSortOptionsDescriptionModule } from "./GridColumnSortOptionsDescriptionModule";
import { GridColumnMoveOptionsDescriptionModule } from "./GridColumnMoveOptionsDescriptionModule";
import { GridColumnPinOptionsDescriptionModule } from "./GridColumnPinOptionsDescriptionModule";
import { GridColumnHideOptionsDescriptionModule } from "./GridColumnHideOptionsDescriptionModule";
import { GridColumnGroupOptionsDescriptionModule } from "./GridColumnGroupOptionsDescriptionModule";
import { GridColumnFilterOptionsDescriptionModule } from "./GridColumnFilterOptionsDescriptionModule";
import { GridColumnSummaryOptionsDescriptionModule } from "./GridColumnSummaryOptionsDescriptionModule";
import { GridColumnButtonOptionsDescriptionModule } from "./GridColumnButtonOptionsDescriptionModule";
import { GridColumnOptionsDescriptionMetadata } from "./GridColumnOptionsDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsDescriptionModule, _super);
    function GridColumnOptionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsDescriptionModule.register = function (a) {
        GridColumnSortOptionsDescriptionModule.register(a);
        GridColumnMoveOptionsDescriptionModule.register(a);
        GridColumnPinOptionsDescriptionModule.register(a);
        GridColumnHideOptionsDescriptionModule.register(a);
        GridColumnGroupOptionsDescriptionModule.register(a);
        GridColumnFilterOptionsDescriptionModule.register(a);
        GridColumnSummaryOptionsDescriptionModule.register(a);
        GridColumnButtonOptionsDescriptionModule.register(a);
        GridColumnOptionsDescriptionMetadata.d(a);
    };
    GridColumnOptionsDescriptionModule.$t = markType(GridColumnOptionsDescriptionModule, 'GridColumnOptionsDescriptionModule');
    return GridColumnOptionsDescriptionModule;
}(Base));
export { GridColumnOptionsDescriptionModule };
